﻿using System;
using System.Collections.ObjectModel;
using System.Drawing;
using System.Web.Script.Serialization;
using System.Web.UI;
using ThinkGeo.MapSuite.Core;
using ThinkGeo.MapSuite.WebEdition;

namespace CallbackSample
{
    public partial class _Default : System.Web.UI.Page, ICallbackEventHandler
    {
        string callbackResult = string.Empty;

        protected void Page_Load(object sender, EventArgs e)
        {
            if (!IsPostBack)
            {
                Map1.BackColor = Color.CadetBlue;
                Map1.CurrentExtent = new RectangleShape(-180, 90, 180, -90);
                Map1.MapUnit = GeographyUnit.DecimalDegree;

                InMemoryFeatureLayer layer = new InMemoryFeatureLayer();
                layer.InternalFeatures.Add(new Feature(new PointShape(50, 50)));
                layer.InternalFeatures.Add(new Feature(new PointShape(20, 20)));
                layer.InternalFeatures.Add(new Feature(new PointShape(40, 70)));
                layer.InternalFeatures.Add(new Feature(new PointShape(80, 10)));

                layer.ZoomLevelSet.ZoomLevel01.DefaultPointStyle = PointStyles.Capital1;
                layer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;

                LayerOverlay overlay = new LayerOverlay("InMemoryLayer");
                overlay.IsBaseOverlay = false;
                overlay.Layers.Add(layer);
                Map1.CustomOverlays.Add(overlay);
            }
        }

        #region ICallbackEventHandler Members

        public string GetCallbackResult()
        {
            return callbackResult;
        }

        public void RaiseCallbackEvent(string eventArgument)
        {
            JavaScriptSerializer serializer = new JavaScriptSerializer();
            if (eventArgument.StartsWith("LonLat"))
            {
                string[] argumentArray = eventArgument.Split(new string[] { ":", "," }, StringSplitOptions.RemoveEmptyEntries);
                PointShape point = new PointShape(Convert.ToDouble(argumentArray[1]), Convert.ToDouble(argumentArray[2]));
                
                LayerOverlay overlay = (LayerOverlay)Map1.CustomOverlays["InMemoryLayer"];
                InMemoryFeatureLayer layer = (InMemoryFeatureLayer)overlay.Layers[0];
                layer.Open();
                Collection<Feature> features = layer.QueryTools.GetFeaturesNearestTo(point, Map1.MapUnit, 1, ReturningColumnsType.AllColumns);
                if (features.Count > 0)
                {
                    BaseShape shape = features[0].GetShape();
                    callbackResult = serializer.Serialize(shape);
                }
            }
        }

        #endregion
    }
}
